pub struct StoreCpiAccounts<'a, 'b> {
pub config_account: (&'b AccountInfo<'a>, bool),
}Expand description
store CPI accounts.
Fields
config_account: (&'b AccountInfo<'a>, bool)The config account to be modified.
Must sign during the first call to store to initialize the account,
or if no signers are configured in the config data.